@@ -1,13 +1,13 @@
 /* mpfr_check -- Check if a floating-point number has not been corrupted.
 
-Copyright 2003, 2004, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+Copyright 2003, 2004, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,9 +16,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include "mpfr-impl.h"
 
@@ -47,7 +47,7 @@ mpfr_check (mpfr_srcptr x)
   /* Check size of mantissa */
   s = MPFR_GET_ALLOC_SIZE(x);
   if (s<=0 || s > MP_SIZE_T_MAX ||
-      MPFR_PREC(x) > ((mp_prec_t)s*BITS_PER_MP_LIMB))
+      MPFR_PREC(x) > ((mpfr_prec_t)s*GMP_NUMB_BITS))
     return 0;
   /* Acces all the mp_limb of the mantissa: may do a seg fault */
   for(i = 0 ; i < s ; i++)
@@ -56,13 +56,13 @@ mpfr_check (mpfr_srcptr x)
   if (MPFR_IS_PURE_FP(x))
     {
       /* Check first mp_limb of mantissa (Must start with a 1 bit) */
-      if ( ((xm[MPFR_LIMB_SIZE(x)-1])>>(BITS_PER_MP_LIMB-1)) == 0)
+      if ( ((xm[MPFR_LIMB_SIZE(x)-1])>>(GMP_NUMB_BITS-1)) == 0)
         return 0;
       /* Check last mp_limb of mantissa */
-      rw = (MPFR_PREC(x) % BITS_PER_MP_LIMB);
+      rw = (MPFR_PREC(x) % GMP_NUMB_BITS);
       if (rw != 0)
         {
-          tmp = MPFR_LIMB_MASK (BITS_PER_MP_LIMB - rw);
+          tmp = MPFR_LIMB_MASK (GMP_NUMB_BITS - rw);
           if ((xm[0] & tmp) != 0)
             return 0;
         }
