@@ -1,6 +1,6 @@
 /* mpfr_erfc -- The Complementary Error Function of a floating-point number
 
-Copyright 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+Copyright 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
@@ -127,6 +127,7 @@ mpfr_erfc (mpfr_ptr y, mpfr_srcptr x, mpfr_rnd_t rnd)
   mpfr_t tmp;
   mpfr_exp_t te, err;
   mpfr_prec_t prec;
+  mpfr_exp_t emin = mpfr_get_emin ();
   MPFR_SAVE_EXPO_DECL (expo);
   MPFR_ZIV_DECL (loop);
 
@@ -149,11 +150,23 @@ mpfr_erfc (mpfr_ptr y, mpfr_srcptr x, mpfr_rnd_t rnd)
 
   if (MPFR_SIGN (x) > 0)
     {
-      /* for x >= 27282, erfc(x) < 2^(-2^30-1) */
-      if (mpfr_cmp_ui (x, 27282) >= 0)
-        return mpfr_underflow (y, (rnd == MPFR_RNDN) ? MPFR_RNDZ : rnd, 1);
+      /* by default, emin = 1-2^30, thus the smallest representable
+         number is 1/2*2^emin = 2^(-2^30):
+         for x >= 27282, erfc(x) < 2^(-2^30-1), and
+         for x >= 1787897414, erfc(x) < 2^(-2^62-1).
+      */
+      if ((emin >= -1073741823 && mpfr_cmp_ui (x, 27282) >= 0) ||
+          mpfr_cmp_ui (x, 1787897414) >= 0)
+        {
+          /* May be incorrect if MPFR_EMAX_MAX >= 2^62. */
+          MPFR_ASSERTN ((MPFR_EMAX_MAX >> 31) >> 31 == 0);
+          return mpfr_underflow (y, (rnd == MPFR_RNDN) ? MPFR_RNDZ : rnd, 1);
+        }
     }
 
+  /* Init stuff */
+  MPFR_SAVE_EXPO_MARK (expo);
+
   if (MPFR_SIGN (x) < 0)
     {
       mpfr_exp_t e = MPFR_EXP(x);
@@ -175,10 +188,11 @@ mpfr_erfc (mpfr_ptr y, mpfr_srcptr x, mpfr_rnd_t rnd)
           if (rnd == MPFR_RNDZ || rnd == MPFR_RNDD)
             {
               mpfr_nextbelow (y);
-              return -1;
+              inex = -1;
             }
           else
-            return 1;
+            inex = 1;
+          goto end;
         }
       else if (e >= 3) /* more accurate test */
         {
@@ -193,7 +207,9 @@ mpfr_erfc (mpfr_ptr y, mpfr_srcptr x, mpfr_rnd_t rnd)
           mpfr_neg (u, x, MPFR_RNDZ); /* 0 <= u <= |x| */
           mpfr_log2 (u, u, MPFR_RNDZ); /* u <= log2(|x|) */
           mpfr_add (t, t, u, MPFR_RNDZ); /* t <= log2|x| + x^2 / log(2) */
-          near_2 = mpfr_cmp_ui (t, MPFR_PREC(y)) >= 0;
+          /* Taking into account that mpfr_exp_t >= mpfr_prec_t */
+          mpfr_set_exp_t (u, MPFR_PREC (y), MPFR_RNDU);
+          near_2 = mpfr_cmp (t, u) >= 0;  /* 1 if PREC(y) <= u <= t <= ... */
           mpfr_clear (t);
           mpfr_clear (u);
           if (near_2)
@@ -201,9 +217,6 @@ mpfr_erfc (mpfr_ptr y, mpfr_srcptr x, mpfr_rnd_t rnd)
         }
     }
 
-  /* Init stuff */
-  MPFR_SAVE_EXPO_MARK (expo);
-
   /* erfc(x) ~ 1, with error < 2^(EXP(x)+1) */
   MPFR_FAST_COMPUTE_IF_SMALL_INPUT (y, __gmpfr_one, - MPFR_GET_EXP (x) - 1,
                                     0, MPFR_SIGN(x) < 0,
