@@ -1,13 +1,13 @@
 /* mpfr_set_uj -- set a MPFR number from a huge machine unsigned integer
 
-Copyright 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+Copyright 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,9 +16,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"       /* for a build within gmp */
@@ -45,13 +45,13 @@ MA 02110-1301, USA. */
 #ifdef _MPFR_H_HAVE_INTMAX_T
 
 int
-mpfr_set_uj (mpfr_t x, uintmax_t j, mp_rnd_t rnd)
+mpfr_set_uj (mpfr_t x, uintmax_t j, mpfr_rnd_t rnd)
 {
   return mpfr_set_uj_2exp (x, j, 0, rnd);
 }
 
 int
-mpfr_set_uj_2exp (mpfr_t x, uintmax_t j, intmax_t e, mp_rnd_t rnd)
+mpfr_set_uj_2exp (mpfr_t x, uintmax_t j, intmax_t e, mpfr_rnd_t rnd)
 {
   unsigned int cnt, i;
   mp_size_t k, len;
@@ -59,7 +59,7 @@ mpfr_set_uj_2exp (mpfr_t x, uintmax_t j, intmax_t e, mp_rnd_t rnd)
   mp_limb_t yp[sizeof(uintmax_t) / sizeof(mp_limb_t)];
   mpfr_t y;
   unsigned long uintmax_bit_size = sizeof(uintmax_t) * CHAR_BIT;
-  unsigned long bpml = BITS_PER_MP_LIMB % uintmax_bit_size;
+  unsigned long bpml = GMP_NUMB_BITS % uintmax_bit_size;
 
   /* Special case */
   if (j == 0)
@@ -78,9 +78,9 @@ mpfr_set_uj_2exp (mpfr_t x, uintmax_t j, intmax_t e, mp_rnd_t rnd)
     limb = yp[0] = j;
   else
     {
-      /* Note: either BITS_PER_MP_LIMB = uintmax_bit_size, then k = 1 the
-         shift j >>= bpml is never done, or BITS_PER_MP_LIMB < uintmax_bit_size
-         and bpml = BITS_PER_MP_LIMB. */
+      /* Note: either GMP_NUMB_BITS = uintmax_bit_size, then k = 1 the
+         shift j >>= bpml is never done, or GMP_NUMB_BITS < uintmax_bit_size
+         and bpml = GMP_NUMB_BITS. */
       for (i = 0; i < k; i++, j >>= bpml)
         yp[i] = j; /* Only the low bits are copied */
 
@@ -110,7 +110,7 @@ mpfr_set_uj_2exp (mpfr_t x, uintmax_t j, intmax_t e, mp_rnd_t rnd)
       else
         MPN_ZERO (yp, len);   /* Zeroing the last limbs */
     }
-  e += k * BITS_PER_MP_LIMB - cnt;    /* Update Expo */
+  e += k * GMP_NUMB_BITS - cnt;    /* Update Expo */
   MPFR_ASSERTD (MPFR_LIMB_MSB(yp[numberof (yp) - 1]) != 0);
 
   /* Check expo underflow / overflow (can't use mpfr_check_range) */
@@ -122,8 +122,8 @@ mpfr_set_uj_2exp (mpfr_t x, uintmax_t j, intmax_t e, mp_rnd_t rnd)
        *   _ |x| < 2^(emin-2), or
        *   _ |x| = 2^(emin-2) and the absolute value of the exact
        *     result is <= 2^(emin-2). */
-      if (rnd == GMP_RNDN && (e+1 < __gmpfr_emin || mpfr_powerof2_raw(y)))
-        rnd = GMP_RNDZ;
+      if (rnd == MPFR_RNDN && (e+1 < __gmpfr_emin || mpfr_powerof2_raw(y)))
+        rnd = MPFR_RNDZ;
       return mpfr_underflow (x, rnd, MPFR_SIGN_POS);
     }
   if (MPFR_UNLIKELY(e > __gmpfr_emax))
