@@ -1,13 +1,13 @@
 /* Test file for mpfr_exp2.
 
-Copyright 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+Copyright 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,9 +16,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,7 +36,7 @@ special_overflow (void)
 {
   mpfr_t x, y;
   int inex;
-  mp_exp_t emin, emax;
+  mpfr_exp_t emin, emax;
 
   emin = mpfr_get_emin ();
   emax = mpfr_get_emax ();
@@ -48,7 +48,7 @@ special_overflow (void)
   mpfr_init2 (y, 24);
 
   mpfr_set_str_binary (x, "0.101100100000000000110100E15");
-  inex = mpfr_exp2 (y, x, GMP_RNDN);
+  inex = mpfr_exp2 (y, x, MPFR_RNDN);
   if (!mpfr_inf_p (y) || inex <= 0)
     {
       printf ("Overflow error.\n");
@@ -71,16 +71,16 @@ emax_m_eps (void)
       mpfr_t x, y;
       int inex, ov;
 
-      mpfr_init2 (x, sizeof(mp_exp_t) * CHAR_BIT * 4);
+      mpfr_init2 (x, sizeof(mpfr_exp_t) * CHAR_BIT * 4);
       mpfr_init2 (y, 8);
-      mpfr_set_si (x, mpfr_get_emax (), GMP_RNDN);
+      mpfr_set_si (x, mpfr_get_emax (), MPFR_RNDN);
 
       mpfr_clear_flags ();
-      inex = mpfr_exp2 (y, x, GMP_RNDN);
+      inex = mpfr_exp2 (y, x, MPFR_RNDN);
       ov = mpfr_overflow_p ();
       if (!ov || !mpfr_inf_p (y) || inex <= 0)
         {
-          printf ("Overflow error for x = emax, GMP_RNDN.\n");
+          printf ("Overflow error for x = emax, MPFR_RNDN.\n");
           mpfr_dump (y);
           printf ("inex = %d, %soverflow\n", inex, ov ? "" : "no ");
           exit (1);
@@ -89,23 +89,23 @@ emax_m_eps (void)
       mpfr_nextbelow (x);
 
       mpfr_clear_flags ();
-      inex = mpfr_exp2 (y, x, GMP_RNDN);
+      inex = mpfr_exp2 (y, x, MPFR_RNDN);
       ov = mpfr_overflow_p ();
       if (!ov || !mpfr_inf_p (y) || inex <= 0)
         {
-          printf ("Overflow error for x = emax - eps, GMP_RNDN.\n");
+          printf ("Overflow error for x = emax - eps, MPFR_RNDN.\n");
           mpfr_dump (y);
           printf ("inex = %d, %soverflow\n", inex, ov ? "" : "no ");
           exit (1);
         }
 
       mpfr_clear_flags ();
-      inex = mpfr_exp2 (y, x, GMP_RNDD);
+      inex = mpfr_exp2 (y, x, MPFR_RNDD);
       ov = mpfr_overflow_p ();
       if (ov || mpfr_inf_p (y) || inex >= 0 ||
           (mpfr_nextabove (y), !mpfr_inf_p (y)))
         {
-          printf ("Overflow error for x = emax - eps, GMP_RNDD.\n");
+          printf ("Overflow error for x = emax - eps, MPFR_RNDD.\n");
           mpfr_dump (y);
           printf ("inex = %d, %soverflow\n", inex, ov ? "" : "no ");
           exit (1);
@@ -120,19 +120,19 @@ static void
 exp_range (void)
 {
   mpfr_t x;
-  mp_exp_t emin;
+  mpfr_exp_t emin;
 
   emin = mpfr_get_emin ();
   set_emin (3);
   mpfr_init2 (x, 8);
-  mpfr_set_ui (x, 5, GMP_RNDN);
-  mpfr_exp2 (x, x, GMP_RNDN);
+  mpfr_set_ui (x, 5, MPFR_RNDN);
+  mpfr_exp2 (x, x, MPFR_RNDN);
   set_emin (emin);
   if (mpfr_nan_p (x) || mpfr_cmp_ui (x, 32) != 0)
     {
       printf ("Error in mpfr_exp2 for x = 5, with emin = 3\n");
       printf ("Expected 32, got ");
-      mpfr_out_str (stdout, 2, 0, x, GMP_RNDN);
+      mpfr_out_str (stdout, 2, 0, x, MPFR_RNDN);
       printf ("\n");
       exit (1);
     }
@@ -144,7 +144,7 @@ overflowed_exp2_0 (void)
 {
   mpfr_t x, y;
   int emax, i, inex, rnd, err = 0;
-  mp_exp_t old_emax;
+  mpfr_exp_t old_emax;
 
   old_emax = mpfr_get_emax ();
 
@@ -153,37 +153,37 @@ overflowed_exp2_0 (void)
 
   for (emax = -1; emax <= 0; emax++)
     {
-      mpfr_set_ui_2exp (y, 1, emax, GMP_RNDN);
+      mpfr_set_ui_2exp (y, 1, emax, MPFR_RNDN);
       mpfr_nextbelow (y);
       set_emax (emax);  /* 1 is not representable. */
       /* and if emax < 0, 1 - eps is not representable either. */
       for (i = -1; i <= 1; i++)
         RND_LOOP (rnd)
           {
-            mpfr_set_si_2exp (x, i, -512 * ABS (i), GMP_RNDN);
+            mpfr_set_si_2exp (x, i, -512 * ABS (i), MPFR_RNDN);
             mpfr_clear_flags ();
-            inex = mpfr_exp2 (x, x, (mp_rnd_t) rnd);
-            if ((i >= 0 || emax < 0 || rnd == GMP_RNDN || rnd == GMP_RNDU) &&
+            inex = mpfr_exp2 (x, x, (mpfr_rnd_t) rnd);
+            if ((i >= 0 || emax < 0 || rnd == MPFR_RNDN || rnd == MPFR_RNDU) &&
                 ! mpfr_overflow_p ())
               {
                 printf ("Error in overflowed_exp2_0 (i = %d, rnd = %s):\n"
                         "  The overflow flag is not set.\n",
-                        i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                        i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                 err = 1;
               }
-            if (rnd == GMP_RNDZ || rnd == GMP_RNDD)
+            if (rnd == MPFR_RNDZ || rnd == MPFR_RNDD)
               {
                 if (inex >= 0)
                   {
                     printf ("Error in overflowed_exp2_0 (i = %d, rnd = %s):\n"
                             "  The inexact value must be negative.\n",
-                            i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                            i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                     err = 1;
                   }
                 if (! mpfr_equal_p (x, y))
                   {
                     printf ("Error in overflowed_exp2_0 (i = %d, rnd = %s):\n"
-                            "  Got ", i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                            "  Got ", i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                     mpfr_print_binary (x);
                     printf (" instead of 0.11111111E%d.\n", emax);
                     err = 1;
@@ -195,13 +195,13 @@ overflowed_exp2_0 (void)
                   {
                     printf ("Error in overflowed_exp2_0 (i = %d, rnd = %s):\n"
                             "  The inexact value must be positive.\n",
-                            i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                            i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                     err = 1;
                   }
                 if (! (mpfr_inf_p (x) && MPFR_SIGN (x) > 0))
                   {
                     printf ("Error in overflowed_exp2_0 (i = %d, rnd = %s):\n"
-                            "  Got ", i, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                            "  Got ", i, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                     mpfr_print_binary (x);
                     printf (" instead of +Inf.\n");
                     err = 1;
@@ -221,7 +221,7 @@ int
 main (int argc, char *argv[])
 {
   mpfr_t x, y;
-  mp_exp_t emin, emax;
+  mpfr_exp_t emin, emax;
 
   tests_start_mpfr ();
 
@@ -232,51 +232,51 @@ main (int argc, char *argv[])
   mpfr_init (x);
   mpfr_init (y);
 
-  mpfr_set_ui (x, 4, GMP_RNDN);
-  mpfr_exp2 (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 4, MPFR_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (y, 16) != 0)
     {
-      printf ("Error for 2^4, GMP_RNDN\n");
+      printf ("Error for 2^4, MPFR_RNDN\n");
       exit (1);
     }
-  mpfr_exp2 (y, x, GMP_RNDD);
+  mpfr_exp2 (y, x, MPFR_RNDD);
   if (mpfr_cmp_ui (y, 16) != 0)
     {
-      printf ("Error for 2^4, GMP_RNDD\n");
+      printf ("Error for 2^4, MPFR_RNDD\n");
       exit (1);
     }
-  mpfr_exp2 (y, x, GMP_RNDU);
+  mpfr_exp2 (y, x, MPFR_RNDU);
   if (mpfr_cmp_ui (y, 16) != 0)
     {
-      printf ("Error for 2^4, GMP_RNDU\n");
+      printf ("Error for 2^4, MPFR_RNDU\n");
       exit (1);
     }
 
-  mpfr_set_si (x, -4, GMP_RNDN);
-  mpfr_exp2 (y, x, GMP_RNDN);
+  mpfr_set_si (x, -4, MPFR_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if (mpfr_cmp_ui_2exp (y, 1, -4) != 0)
     {
-      printf ("Error for 2^(-4), GMP_RNDN\n");
+      printf ("Error for 2^(-4), MPFR_RNDN\n");
       exit (1);
     }
-  mpfr_exp2 (y, x, GMP_RNDD);
+  mpfr_exp2 (y, x, MPFR_RNDD);
   if (mpfr_cmp_ui_2exp (y, 1, -4) != 0)
     {
-      printf ("Error for 2^(-4), GMP_RNDD\n");
+      printf ("Error for 2^(-4), MPFR_RNDD\n");
       exit (1);
     }
-  mpfr_exp2 (y, x, GMP_RNDU);
+  mpfr_exp2 (y, x, MPFR_RNDU);
   if (mpfr_cmp_ui_2exp (y, 1, -4) != 0)
     {
-      printf ("Error for 2^(-4), GMP_RNDU\n");
+      printf ("Error for 2^(-4), MPFR_RNDU\n");
       exit (1);
     }
 
   mpfr_set_prec (x, 53);
   mpfr_set_prec (y, 53);
   mpfr_set_str (x, /*-1683977482443233.0 / 2199023255552.0*/
-                "-7.6578429909351734750089235603809357e2", 10, GMP_RNDN);
-  mpfr_exp2 (y, x, GMP_RNDN);
+                "-7.6578429909351734750089235603809357e2", 10, MPFR_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if (mpfr_cmp_str1 (y, "2.991959870867646566478e-231"))
     {
       printf ("Error for x=-1683977482443233/2^41\n");
@@ -288,8 +288,8 @@ main (int argc, char *argv[])
   /* save emin */
   emin = mpfr_get_emin ();
   set_emin (-10);
-  mpfr_set_si (x, -12, GMP_RNDN);
-  mpfr_exp2 (y, x, GMP_RNDN);
+  mpfr_set_si (x, -12, MPFR_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (y, 0) || mpfr_sgn (y) < 0)
     {
       printf ("Error for x=emin-2, RNDN\n");
@@ -303,8 +303,8 @@ main (int argc, char *argv[])
   /* save emax */
   emax = mpfr_get_emax ();
   set_emax (10);
-  mpfr_set_ui (x, 11, GMP_RNDN);
-  mpfr_exp2 (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 11, MPFR_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if (!mpfr_inf_p (y) || mpfr_sgn (y) < 0)
     {
       printf ("Error for x=emax+1, RNDN\n");
@@ -315,7 +315,7 @@ main (int argc, char *argv[])
 
   MPFR_SET_INF(x);
   MPFR_SET_POS(x);
-  mpfr_exp2 (y, x, GMP_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if(!MPFR_IS_INF(y))
     {
       printf ("evaluation of function in INF does not return INF\n");
@@ -323,7 +323,7 @@ main (int argc, char *argv[])
     }
 
   MPFR_CHANGE_SIGN(x);
-  mpfr_exp2 (y, x, GMP_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if(!MPFR_IS_ZERO(y))
     {
       printf ("evaluation of function in -INF does not return 0\n");
@@ -331,22 +331,22 @@ main (int argc, char *argv[])
     }
 
   MPFR_SET_NAN(x);
-  mpfr_exp2 (y, x, GMP_RNDN);
+  mpfr_exp2 (y, x, MPFR_RNDN);
   if(!MPFR_IS_NAN(y))
     {
       printf ("evaluation of function in NaN does not return NaN\n");
       exit (1);
     }
 
-  if ((mp_exp_unsigned_t) 8 << 31 != 0 ||
-      mpfr_get_emax () <= (mp_exp_unsigned_t) 100000 * 100000)
+  if ((mpfr_uexp_t) 8 << 31 != 0 ||
+      mpfr_get_emax () <= (mpfr_uexp_t) 100000 * 100000)
     {
       /* emax <= 10000000000 */
       mpfr_set_prec (x, 40);
       mpfr_set_prec (y, 40);
-      mpfr_set_str (x, "10000000000.5", 10, GMP_RNDN);
+      mpfr_set_str (x, "10000000000.5", 10, MPFR_RNDN);
       mpfr_clear_flags ();
-      mpfr_exp2 (y, x, GMP_RNDN);
+      mpfr_exp2 (y, x, MPFR_RNDN);
       if (!(MPFR_IS_INF (y) && MPFR_IS_POS (y) && mpfr_overflow_p ()))
         {
           printf ("exp2(10000000000.5) should overflow.\n");
@@ -357,7 +357,7 @@ main (int argc, char *argv[])
   mpfr_set_prec (x, 2);
   mpfr_set_prec (y, 2);
   mpfr_set_str_binary (x, "-1.0E-26");
-  mpfr_exp2 (y, x, GMP_RNDD);
+  mpfr_exp2 (y, x, MPFR_RNDD);
   mpfr_set_str_binary (x, "1.1E-1");
   if (mpfr_cmp (x, y))
     {
