@@ -1,24 +1,24 @@
 /* Test file for mpfr_expm1.
 
-Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,10 +27,10 @@ MA 02110-1301, USA. */
 
 #ifdef CHECK_EXTERNAL
 static int
-test_expm1 (mpfr_ptr a, mpfr_srcptr b, mp_rnd_t rnd_mode)
+test_expm1 (mpfr_ptr a, mpfr_srcptr b, mpfr_rnd_t rnd_mode)
 {
   int res;
-  int ok = rnd_mode == GMP_RNDN && mpfr_number_p (b) && mpfr_get_prec (a)>=53;
+  int ok = rnd_mode == MPFR_RNDN && mpfr_number_p (b) && mpfr_get_prec (a)>=53;
   if (ok)
     {
       mpfr_print_raw (b);
@@ -49,6 +49,8 @@ test_expm1 (mpfr_ptr a, mpfr_srcptr b, mp_rnd_t rnd_mode)
 #endif
 
 #define TEST_FUNCTION test_expm1
+#define TEST_RANDOM_EMIN -36
+#define TEST_RANDOM_EMAX 36
 #include "tgeneric.c"
 
 static void
@@ -61,7 +63,7 @@ special (void)
   mpfr_init (y);
 
   mpfr_set_nan (x);
-  test_expm1 (y, x, GMP_RNDN);
+  test_expm1 (y, x, MPFR_RNDN);
   if (!mpfr_nan_p (y))
     {
       printf ("Error for expm1(NaN)\n");
@@ -69,7 +71,7 @@ special (void)
     }
 
   mpfr_set_inf (x, 1);
-  test_expm1 (y, x, GMP_RNDN);
+  test_expm1 (y, x, MPFR_RNDN);
   if (!mpfr_inf_p (y) || mpfr_sgn (y) < 0)
     {
       printf ("Error for expm1(+Inf)\n");
@@ -77,23 +79,23 @@ special (void)
     }
 
   mpfr_set_inf (x, -1);
-  test_expm1 (y, x, GMP_RNDN);
+  test_expm1 (y, x, MPFR_RNDN);
   if (mpfr_cmp_si (y, -1))
     {
       printf ("Error for expm1(-Inf)\n");
       exit (1);
     }
 
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  test_expm1 (y, x, GMP_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  test_expm1 (y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (y, 0) || mpfr_sgn (y) < 0)
     {
       printf ("Error for expm1(+0)\n");
       exit (1);
     }
 
-  mpfr_neg (x, x, GMP_RNDN);
-  test_expm1 (y, x, GMP_RNDN);
+  mpfr_neg (x, x, MPFR_RNDN);
+  test_expm1 (y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (y, 0) || mpfr_sgn (y) > 0)
     {
       printf ("Error for expm1(-0)\n");
@@ -103,21 +105,21 @@ special (void)
   /* Check overflow of expm1(x) */
   mpfr_clear_flags ();
   mpfr_set_str_binary (x, "1.1E1000000000");
-  i = test_expm1 (x, x, GMP_RNDN);
+  i = test_expm1 (x, x, MPFR_RNDN);
   MPFR_ASSERTN (MPFR_IS_INF (x) && MPFR_SIGN (x) > 0);
   MPFR_ASSERTN (mpfr_overflow_p ());
   MPFR_ASSERTN (i == 1);
 
   mpfr_clear_flags ();
   mpfr_set_str_binary (x, "1.1E1000000000");
-  i = test_expm1 (x, x, GMP_RNDU);
+  i = test_expm1 (x, x, MPFR_RNDU);
   MPFR_ASSERTN (MPFR_IS_INF (x) && MPFR_SIGN (x) > 0);
   MPFR_ASSERTN (mpfr_overflow_p ());
   MPFR_ASSERTN (i == 1);
 
   mpfr_clear_flags ();
   mpfr_set_str_binary (x, "1.1E1000000000");
-  i = test_expm1 (x, x, GMP_RNDD);
+  i = test_expm1 (x, x, MPFR_RNDD);
   MPFR_ASSERTN (!MPFR_IS_INF (x) && MPFR_SIGN (x) > 0);
   MPFR_ASSERTN (mpfr_overflow_p ());
   MPFR_ASSERTN (i == -1);
@@ -126,26 +128,26 @@ special (void)
   mpfr_set_prec (x, 2);
   mpfr_clear_flags ();
   mpfr_set_str_binary (x, "-1.1E1000000000");
-  i = test_expm1 (x, x, GMP_RNDN);
+  i = test_expm1 (x, x, MPFR_RNDN);
   MPFR_ASSERTN (mpfr_cmp_si (x, -1) == 0);
   MPFR_ASSERTN (!mpfr_overflow_p () && !mpfr_underflow_p ());
   MPFR_ASSERTN (i == -1);
 
   mpfr_set_str_binary (x, "-1.1E1000000000");
-  i = test_expm1 (x, x, GMP_RNDD);
+  i = test_expm1 (x, x, MPFR_RNDD);
   MPFR_ASSERTN (mpfr_cmp_si (x, -1) == 0);
   MPFR_ASSERTN (!mpfr_overflow_p () && !mpfr_underflow_p ());
   MPFR_ASSERTN (i == -1);
 
   mpfr_set_str_binary (x, "-1.1E1000000000");
-  i = test_expm1 (x, x, GMP_RNDZ);
-  MPFR_ASSERTN (mpfr_cmp_str (x, "-0.11", 2, GMP_RNDN) == 0);
+  i = test_expm1 (x, x, MPFR_RNDZ);
+  MPFR_ASSERTN (mpfr_cmp_str (x, "-0.11", 2, MPFR_RNDN) == 0);
   MPFR_ASSERTN (!mpfr_overflow_p () && !mpfr_underflow_p ());
   MPFR_ASSERTN (i == 1);
 
   mpfr_set_str_binary (x, "-1.1E1000000000");
-  i = test_expm1 (x, x, GMP_RNDU);
-  MPFR_ASSERTN (mpfr_cmp_str (x, "-0.11", 2, GMP_RNDN) == 0);
+  i = test_expm1 (x, x, MPFR_RNDU);
+  MPFR_ASSERTN (mpfr_cmp_str (x, "-0.11", 2, MPFR_RNDN) == 0);
   MPFR_ASSERTN (!mpfr_overflow_p () && !mpfr_underflow_p ());
   MPFR_ASSERTN (i == 1);
 
@@ -163,6 +165,8 @@ main (int argc, char *argv[])
   test_generic (2, 100, 100);
 
   data_check ("data/expm1", mpfr_expm1, "mpfr_expm1");
+  bad_cases (mpfr_expm1, mpfr_log1p, "mpfr_expm1", 256, -256, 255,
+             4, 128, 800, 40);
 
   tests_end_mpfr ();
   return 0;
