@@ -1,29 +1,28 @@
 /* Test file for mpfr_set_d and mpfr_get_d.
 
-Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <float.h>
-#include <time.h>
 
 #include "mpfr-test.h"
 
@@ -32,7 +31,8 @@ main (int argc, char *argv[])
 {
   mpfr_t x, y, z;
   unsigned long k, n;
-  double d, dd;
+  volatile double d;
+  double dd;
 
   tests_start_mpfr ();
   mpfr_test_init ();
@@ -65,29 +65,52 @@ main (int argc, char *argv[])
 
   mpfr_init (x);
 
-  d = 0.0;
-  mpfr_set_d (x, d, GMP_RNDN);
-  MPFR_ASSERTN(mpfr_cmp_ui (x, 0) == 0 && MPFR_IS_POS(x));
-  mpfr_set_d (x, -d, GMP_RNDN);
-  MPFR_ASSERTN(mpfr_cmp_ui (x, 0) == 0 && MPFR_IS_NEG(x));
-
   mpfr_set_nan (x);
-  d = mpfr_get_d (x, GMP_RNDN);
-  MPFR_ASSERTN (DOUBLE_ISNAN (d));
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  mpfr_set_d (x, d, GMP_RNDN);
-  MPFR_ASSERTN(mpfr_nan_p (x));
+  d = mpfr_get_d (x, MPFR_RNDN);
+  if (! DOUBLE_ISNAN (d))
+    {
+      printf ("ERROR for NAN (1)\n");
+#ifdef MPFR_NANISNAN
+      printf ("The reason is that NAN == NAN. Please look at the configure "
+              "output\nand Section \"In case of problem\" of the INSTALL "
+              "file.\n");
+#endif
+      exit (1);
+    }
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  mpfr_set_d (x, d, MPFR_RNDN);
+  if (! mpfr_nan_p (x))
+    {
+      printf ("ERROR for NAN (2)\n");
+#ifdef MPFR_NANISNAN
+      printf ("The reason is that NAN == NAN. Please look at the configure "
+              "output\nand Section \"In case of problem\" of the INSTALL "
+              "file.\n");
+#endif
+      exit (1);
+    }
+
+  d = 0.0;
+  mpfr_set_d (x, d, MPFR_RNDN);
+  MPFR_ASSERTN(mpfr_cmp_ui (x, 0) == 0 && MPFR_IS_POS(x));
+  d = -d;
+  mpfr_set_d (x, d, MPFR_RNDN);
+  if (mpfr_cmp_ui (x, 0) != 0 || MPFR_IS_POS(x))
+    {
+      printf ("Error in mpfr_set_d on -0\n");
+      exit (1);
+    }
 
   mpfr_set_inf (x, 1);
-  d = mpfr_get_d (x, GMP_RNDN);
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  mpfr_set_d (x, d, GMP_RNDN);
+  d = mpfr_get_d (x, MPFR_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  mpfr_set_d (x, d, MPFR_RNDN);
   MPFR_ASSERTN(mpfr_inf_p (x) && mpfr_sgn (x) > 0);
 
   mpfr_set_inf (x, -1);
-  d = mpfr_get_d (x, GMP_RNDN);
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  mpfr_set_d (x, d, GMP_RNDN);
+  d = mpfr_get_d (x, MPFR_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  mpfr_set_d (x, d, MPFR_RNDN);
   MPFR_ASSERTN(mpfr_inf_p (x) && mpfr_sgn (x) < 0);
 
   mpfr_set_prec (x, 2);
@@ -97,12 +120,12 @@ main (int argc, char *argv[])
   for (n=0; n<52; n++, d /= 2.0)
     if (d != 0.0) /* should be 2^(-1022-n) */
       {
-        mpfr_set_d (x, d, GMP_RNDN);
+        mpfr_set_d (x, d, MPFR_RNDN);
         if (mpfr_cmp_ui_2exp (x, 1, -1022-n))
           {
             printf ("Wrong result for d=2^(%ld), ", -1022-n);
             printf ("got ");
-            mpfr_out_str (stdout, 10, 10, x, GMP_RNDN);
+            mpfr_out_str (stdout, 10, 10, x, MPFR_RNDN);
             printf ("\n");
             mpfr_print_binary (x);
             puts ("");
@@ -112,14 +135,14 @@ main (int argc, char *argv[])
 
    /* checks that rounds to nearest sets the last
      bit to zero in case of equal distance */
-   mpfr_set_d (x, 5.0, GMP_RNDN);
+   mpfr_set_d (x, 5.0, MPFR_RNDN);
    if (mpfr_cmp_ui (x, 4))
      {
        printf ("Error in tset_d: expected 4.0, got ");
        mpfr_print_binary (x); putchar('\n');
        exit (1);
      }
-   mpfr_set_d (x, -5.0, GMP_RNDN);
+   mpfr_set_d (x, -5.0, MPFR_RNDN);
    if (mpfr_cmp_si (x, -4))
      {
        printf ("Error in tset_d: expected -4.0, got ");
@@ -127,7 +150,7 @@ main (int argc, char *argv[])
        exit (1);
      }
 
-   mpfr_set_d (x, 9.84891017624509146344e-01, GMP_RNDU);
+   mpfr_set_d (x, 9.84891017624509146344e-01, MPFR_RNDU);
    if (mpfr_cmp_ui (x, 1))
      {
        printf ("Error in tset_d: expected 1.0, got ");
@@ -136,7 +159,7 @@ main (int argc, char *argv[])
      }
 
   mpfr_init2 (z, 32);
-  mpfr_set_d (z, 1.0, (mp_rnd_t) 0);
+  mpfr_set_d (z, 1.0, (mpfr_rnd_t) 0);
   if (mpfr_cmp_ui (z, 1))
     {
       mpfr_print_binary (z); puts ("");
@@ -145,7 +168,7 @@ main (int argc, char *argv[])
     }
   mpfr_set_prec (x, 53);
   mpfr_init2 (y, 53);
-  mpfr_set_d (x, d=-1.08007920352320089721e+150, (mp_rnd_t) 0);
+  mpfr_set_d (x, d=-1.08007920352320089721e+150, (mpfr_rnd_t) 0);
   if (mpfr_get_d1 (x) != d)
     {
       mpfr_print_binary (x); puts ("");
@@ -154,9 +177,9 @@ main (int argc, char *argv[])
       exit (1);
     }
 
-  mpfr_set_d (x, 8.06294740693074521573e-310, (mp_rnd_t) 0);
+  mpfr_set_d (x, 8.06294740693074521573e-310, (mpfr_rnd_t) 0);
   d = -6.72658901114033715233e-165;
-  mpfr_set_d (x, d, (mp_rnd_t) 0);
+  mpfr_set_d (x, d, (mpfr_rnd_t) 0);
   if (d != mpfr_get_d1 (x))
     {
       mpfr_print_binary (x);
@@ -165,6 +188,7 @@ main (int argc, char *argv[])
               d, mpfr_get_d1 (x));
       exit (1);
     }
+
   n = (argc==1) ? 500000 : atoi(argv[1]);
   for (k = 1; k <= n; k++)
     {
@@ -177,7 +201,7 @@ main (int argc, char *argv[])
 #else
       while (ABS(d) < DBL_MIN);
 #endif
-      mpfr_set_d (x, d, (mp_rnd_t) 0);
+      mpfr_set_d (x, d, (mpfr_rnd_t) 0);
       dd = mpfr_get_d1 (x);
       if (d != dd && !(Isnan(d) && Isnan(dd)))
         {
